@@ -1,5 +1,3 @@
-context("implementation [ADMM]")
-
 coef_tol <- 1e-4
 
 if (requireNamespace("prefmod", quietly = TRUE)) {
@@ -11,25 +9,25 @@ if (requireNamespace("prefmod", quietly = TRUE)) {
         ## linear predictor, no new data
         expect_equal(predict(res0_PLADMM),
                      log(res0_PLADMM[["tilde_pi"]]),
-                     tol = coef_tol)
+                     tolerance = coef_tol)
         ## same returned by fitted
         expect_equal(predict(res0_PLADMM),
                      fitted(res0_PLADMM),
-                     tol = coef_tol)
+                     tolerance = coef_tol)
         ## linear predictor, new data
         expect_equal(unname(predict(res0_PLADMM, newdata = features[1:2,])),
                      unname(predict(res0_PLADMM)[1:2]),
-                     tol = coef_tol)
+                     tolerance = coef_tol)
         ## itempar, no new data
         expect_equal(predict(res0_PLADMM, type = "itempar"),
                      c(itempar(res0_PLADMM)),
-                     tol = coef_tol)
+                     tolerance = coef_tol)
         ## itempar, new data
         worth <- itempar(res0_PLADMM)[1:2]
         expect_equal(unname(predict(res0_PLADMM, type = "itempar",
                                     newdata = features[1:2,])),
                      unname(worth/sum(worth)),
-                     tol = coef_tol)
+                     tolerance = coef_tol)
     })
 
     if (requireNamespace("BradleyTerry2", quietly = TRUE)) {
@@ -52,12 +50,12 @@ if (requireNamespace("prefmod", quietly = TRUE)) {
             ability <- c(BTabilities(res_BTm)[, "ability"])
             expect_equal(predict(res_PLADMM) - coef(res_PLADMM)[1],
                          ability,
-                         coef_tol)
+                         tolerance = coef_tol)
             # expect s.e. of log-worth to be the same
             se <- c(BTabilities(res_BTm)[, "s.e."])
             expect_equal(predict(res_PLADMM, se.fit = TRUE)$se.fit,
                          se,
-                         coef_tol)
+                         tolerance = coef_tol)
             # expect predicted item worth correct for new data
             pred1 <- predict(res_PLADMM, type = "itempar", ref = 2:3,
                              se.fit = TRUE)
@@ -66,10 +64,10 @@ if (requireNamespace("prefmod", quietly = TRUE)) {
                              se.fit = TRUE)
             expect_equal(unname(pred1$fit[2:3]),
                          unname(pred2$fit),
-                         coef_tol)
+                         tolerance = coef_tol)
             expect_equal(unname(pred1$se.fit[2:3]),
                          unname(pred2$se.fit),
-                         coef_tol)
+                         tolerance = coef_tol)
         })
 
         test_that("PLADMM predict works for PL with other contrasts [salad pairs]", {
@@ -93,12 +91,12 @@ if (requireNamespace("prefmod", quietly = TRUE)) {
             ability <- c(BTabilities(res_BTm)[, "ability"])
             expect_equal(predict(res_PLADMM) - coef(res_PLADMM)[1],
                          ability,
-                         coef_tol)
+                         tolerance = coef_tol)
             # expect s.e. of log-worth to be the same
             se <- c(BTabilities(res_BTm)[, "s.e."])
             expect_equal(predict(res_PLADMM, se.fit = TRUE)$se.fit,
                          se,
-                         coef_tol)
+                         tolerance = coef_tol)
             # expect predicted item worth correct for new data
             pred1 <- predict(res_PLADMM, type = "itempar", ref = 2:3,
                              se.fit = TRUE)
@@ -107,10 +105,10 @@ if (requireNamespace("prefmod", quietly = TRUE)) {
                              se.fit = TRUE)
             expect_equal(unname(pred1$fit[2:3]),
                          unname(pred2$fit),
-                         coef_tol)
+                         tolerance = coef_tol)
             expect_equal(unname(pred1$se.fit[2:3]),
                          unname(pred2$se.fit),
-                         coef_tol)
+                         tolerance = coef_tol)
         })
     }
 }
